summaryrefslogtreecommitdiff
path: root/libusb/libusb.h
diff options
context:
space:
mode:
Diffstat (limited to 'libusb/libusb.h')
-rw-r--r--libusb/libusb.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/libusb/libusb.h b/libusb/libusb.h
index fd231ea..1dc12f8 100644
--- a/libusb/libusb.h
+++ b/libusb/libusb.h
@@ -951,20 +951,20 @@ enum libusb_capability {
/** \ingroup lib
* Log message levels.
* - LOG_LEVEL_NONE (0) : no messages ever printed by the library (default)
* - LOG_LEVEL_ERROR (1) : error messages are printed to stderr
* - LOG_LEVEL_WARNING (2) : warning and error messages are printed to stderr
* - LOG_LEVEL_INFO (3) : informational messages are printed to stdout, warning
* and error messages are printed to stderr
* - LOG_LEVEL_DEBUG (4) : debug and informational messages are printed to stdout,
* warnings and errors to stderr
*/
-enum usbi_log_level {
- LOG_LEVEL_NONE = 0,
- LOG_LEVEL_ERROR,
- LOG_LEVEL_WARNING,
- LOG_LEVEL_INFO,
- LOG_LEVEL_DEBUG,
+enum libusb_log_level {
+ LIBUSB_LOG_LEVEL_NONE = 0,
+ LIBUSB_LOG_LEVEL_ERROR,
+ LIBUSB_LOG_LEVEL_WARNING,
+ LIBUSB_LOG_LEVEL_INFO,
+ LIBUSB_LOG_LEVEL_DEBUG,
};
int LIBUSB_CALL libusb_init(libusb_context **ctx);
@@ -951,20 +951,20 @@ enum libusb_capability {
/** \ingroup lib
* Log message levels.
- * - LOG_LEVEL_NONE (0) : no messages ever printed by the library (default)
- * - LOG_LEVEL_ERROR (1) : error messages are printed to stderr
- * - LOG_LEVEL_WARNING (2) : warning and error messages are printed to stderr
- * - LOG_LEVEL_INFO (3) : informational messages are printed to stdout, warning
+ * - LIBUSB_LOG_LEVEL_NONE (0) : no messages ever printed by the library (default)
+ * - LIBUSB_LOG_LEVEL_ERROR (1) : error messages are printed to stderr
+ * - LIBUSB_LOG_LEVEL_WARNING (2) : warning and error messages are printed to stderr
+ * - LIBUSB_LOG_LEVEL_INFO (3) : informational messages are printed to stdout, warning
* and error messages are printed to stderr
@@ -951,20 +951,20 @@ enum libusb_capability {
* and error messages are printed to stderr
- * - LOG_LEVEL_DEBUG (4) : debug and informational messages are printed to stdout,
+ * - LIBUSB_LOG_LEVEL_DEBUG (4) : debug and informational messages are printed to stdout,
* warnings and errors to stderr
*/